@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013-2016 Montel Laurent <montel@kde.org>
+  Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -21,17 +21,15 @@
 #include <QObject>
 #include "ksieveui_export.h"
 
-#include <QPointer>
-
 class QWidget;
-namespace KSieveUi
-{
+namespace KSieveUi {
 class VacationManagerPrivate;
+class SieveImapPasswordProvider;
 class KSIEVEUI_EXPORT VacationManager : public QObject
 {
     Q_OBJECT
 public:
-    explicit VacationManager(QWidget *parent);
+    explicit VacationManager(SieveImapPasswordProvider *passwordProvider, QWidget *parent);
     ~VacationManager();
 
     void checkVacation();
@@ -41,14 +39,14 @@ public Q_SLOTS:
 
 Q_SIGNALS:
     void updateVacationScriptStatus(bool active, const QString &serverName);
-    void editVacation();
 
-private Q_SLOTS:
+private:
     void slotDialogCanceled();
     void slotDialogOk();
     void slotUpdateVacationScriptStatus(bool active, const QString &serverName);
 
 private:
+    Q_DISABLE_COPY(VacationManager)
     VacationManagerPrivate *const d;
 };
 }
